==> alabaster.files_1.0.0.tgz: alabaster.files/doc/userguide.R <==
## ----echo=FALSE---------------------------------------------------------------
library(BiocStyle)
self <- Githubpkg("ArtifactDB/alabaster.files")
knitr::opts_chunk$set(error=FALSE, warning=FALSE, message=FALSE)

## -----------------------------------------------------------------------------
bam.file <- system.file("extdata", "ex1.bam", package="Rsamtools", mustWork=TRUE)
bam.index <- paste0(bam.file, ".bai")

## -----------------------------------------------------------------------------
library(alabaster.files)
library(S4Vectors)
wrapped.bam <- BamWrapper(bam.file, index=bam.index)
metadata(wrapped.bam) <- list(foo="bar")

## -----------------------------------------------------------------------------
dir <- tempfile()
dir.create(dir)
saveLocalObject(wrapped.bam, dir, path="my_bam")

## -----------------------------------------------------------------------------
readLocalObject(dir, "my_bam")

## -----------------------------------------------------------------------------
df <- DataFrame(Sample=LETTERS[1:4])

# Adding a column of assorted wrapper files:
df$File <- list(
    wrapped.bam,
    BedWrapper(system.file("tests", "test.bed", package = "rtracklayer")),
    BigBedWrapper(system.file("tests", "test.bb", package = "rtracklayer")),
    GffWrapper(system.file("tests", "test.gtf", package = "rtracklayer"))
)

# Saving it all to the staging directory:
dir <- tempfile()
dir.create(dir)
saveLocalObject(df, dir, path="stuff")

# Now reading it back in:
roundtrip <- readLocalObject(dir, "stuff")
roundtrip$File

## -----------------------------------------------------------------------------
sessionInfo()

==> alabaster.files_1.5.0.tgz: alabaster.files/doc/userguide.R <==
## ----echo=FALSE---------------------------------------------------------------
library(BiocStyle)
self <- Biocpkg("alabaster.files")
knitr::opts_chunk$set(error=FALSE, warning=FALSE, message=FALSE)

## -----------------------------------------------------------------------------
bam.file <- system.file("extdata", "ex1.bam", package="Rsamtools", mustWork=TRUE)
bam.index <- paste0(bam.file, ".bai")

## -----------------------------------------------------------------------------
library(alabaster.files)
library(S4Vectors)
wrapped.bam <- BamFileReference(bam.file, index=bam.index)

## -----------------------------------------------------------------------------
dir <- tempfile()
saveObject(wrapped.bam, dir)

## -----------------------------------------------------------------------------
readObject(dir)

## -----------------------------------------------------------------------------
df <- DataFrame(Sample=LETTERS[1:4])

# Adding a column of assorted wrapper files:
df$File <- list(
    wrapped.bam,
    BigWigFileReference(system.file("tests", "test.bw", package = "rtracklayer")),
    BigBedFileReference(system.file("tests", "test.bb", package = "rtracklayer")),
    BcfFileReference(system.file("extdata", "ex1.bcf.gz", package = "Rsamtools"))
)

# Saving it all to the staging directory:
dir <- tempfile()
saveObject(df, dir)

# Now reading it back in:
roundtrip <- readObject(dir)
roundtrip$File

## -----------------------------------------------------------------------------
sessionInfo()
